@@ -10,7 +10,7 @@ from .backend import *
 import h5py
 
 class Meshoid(object):
-    def __init__(self, pos, m=None, hsml=None, des_ngb=None, boxsize=-1, verbose=False, particle_mask=None, n_jobs=1):
+    def __init__(self, pos, m=None, hsml=None, des_ngb=None, boxsize=None, verbose=False, particle_mask=None, n_jobs=1):
         """
         Creates a Meshoid object instance given at least the positions of the particles.
         
@@ -339,9 +339,8 @@ class Meshoid(object):
             ngbdist, ngb = self.tree.query(gridcoords, workers=self.n_jobs)
             f_interp = f[ngb].reshape((res,res,res))
         elif method=='kernel':
-            h = np.clip(self.hsml, 2 * size/(res-1), 1e100)
+            h = np.clip(self.hsml, size/(res-1), 1e100)
             f_interp = WeightedGridInterp3D(f, weights, self.pos, h, center, size, res=res,box_size=self.boxsize)
-                   
         return f_interp
 
     def DepositToGrid(self, f, weights=None, size=None, center=None, res=128):
@@ -352,7 +351,7 @@ class Meshoid(object):
         if size is None: size = self.L
         if weights is None: weights = self.m
 
-        h = np.clip(self.hsml, 2 * size/(res-1), 1e100)
+        h = np.clip(self.hsml, size/(res-1), 1e100)
         f_grid = GridDensity(f, self.pos, h, center, size, res=res,box_size=self.boxsize)
                    
         return f_grid
